@@ -36,22 +36,6 @@ DBIx::DBO::Query - An OO interface to SQL queries and results.  Encapsulates an
 
 =head1 METHODS
 
-=head2 dbh
-
-The read-write C<DBI> handle.
-
-=head2 rdbh
-
-The read-only C<DBI> handle, or if there is no read-only connection, the read-write C<DBI> handle.
-
-=head2 do
-
-  $dbo->do($statement)         or die $dbo->dbh->errstr;
-  $dbo->do($statement, \%attr) or die $dbo->dbh->errstr;
-  $dbo->do($statement, \%attr, @bind_values) or die ...
-
-This provides access to L<DBI-E<gt>do|DBI/"do"> method. It defaults to using the read-write C<DBI> handle.
-
 =cut
 
 sub _new {
@@ -69,6 +53,75 @@ sub _new {
     return wantarray ? ($me, $me->tables) : $me;
 }
 
+=head2 reset
+
+  $query->reset;
+
+Reset the query, start over with a clean slate.
+
+=cut
+
+sub reset {
+    my $me = shift;
+    $me->unwhere;
+#    $me->{IsDistinct} = 0;
+    $me->show;
+    $me->group_by;
+    $me->order_by;
+    $me->limit;
+}
+
+=head2 tables
+
+Return a list of L<DBIx::DBO::Table|DBIx::DBO::Table> objects for this query.
+
+=cut
+
+sub tables {
+    my $me = shift;
+    @{$me->{Tables}};
+}
+
+sub _table_idx {
+    my ($me, $tbl) = @_;
+    for my $i (0 .. $#{$me->{Tables}}) {
+        return $i if $tbl == $me->{Tables}[$i];
+    }
+    return undef;
+}
+
+sub _table_alias {
+    my ($me, $tbl) = @_;
+    my $i = $me->_table_idx($tbl);
+    ouch 'The table is not in this query' unless defined $i;
+    @{$me->{Tables}} > 1 ? 't'.($i + 1) : ();
+}
+
+=head2 show
+
+  $query->show(@columns);
+  $query->show($table1 ** 'id', {FUNC => 'UCASE(?)', COL => 'name', AS => 'NAME'}, ...
+
+Specify which columns to show as an array. If the array is empty all columns will be shown.
+
+=cut
+
+sub show {
+    my $me = shift;
+    undef $me->{sql};
+    undef $me->{build_data}{show};
+    undef @{$me->{build_data}{Showing}};
+    for my $fld (@_) {
+        if (blessed $fld and $fld->isa('DBIx::DBO::Table')) {
+            ouch 'Invalid table field' unless defined $me->_table_idx($fld);
+            push @{$me->{build_data}{Showing}}, $fld;
+            next;
+        }
+        # If the $fld is just a scalar use it as a column name not a value
+        push @{$me->{build_data}{Showing}}, [ $me->_parse_col_val($fld) ];
+    }
+}
+
 =head2 join_table
 
   $query->join_table($table, $join_type);
@@ -108,80 +161,6 @@ sub join_table {
     return $tbl;
 }
 
-=head2 tables
-
-Return a list of L<DBIx::DBO::Table|DBIx::DBO::Table> objects for this query.
-
-=cut
-
-sub tables {
-    my $me = shift;
-    @{$me->{Tables}};
-}
-
-sub _table_idx {
-    my ($me, $tbl) = @_;
-    for my $i (0 .. $#{$me->{Tables}}) {
-        return $i if $tbl == $me->{Tables}[$i];
-    }
-    return undef;
-}
-
-sub _table_alias {
-    my ($me, $tbl) = @_;
-    my $i = $me->_table_idx($tbl);
-    ouch 'The table is not in this query' unless defined $i;
-    @{$me->{Tables}} > 1 ? 't'.($i + 1) : ();
-}
-
-sub _showing {
-    my $me = shift;
-    @{$me->{build_data}{Showing}} ? @{$me->{build_data}{Showing}} : @{$me->{Tables}};
-}
-
-=head2 reset
-
-  $query->reset;
-
-Reset the query, start over with a clean slate.
-
-=cut
-
-sub reset {
-    my $me = shift;
-    $me->unwhere;
-#    $me->{IsDistinct} = 0;
-    undef @{$me->{build_data}{Showing}};
-    undef @{$me->{build_data}{GroupBy}};
-    undef @{$me->{build_data}{OrderBy}};
-    undef $me->{build_data}{LimitOffset};
-}
-
-=head2 show
-
-  $query->show(@columns);
-  $query->show($table1 ** 'id', {FUNC => 'UCASE(?)', COL => 'name', AS => 'NAME'}, ...
-
-Specify which columns to show as an array. If the array is empty all columns will be shown.
-
-=cut
-
-sub show {
-    my $me = shift;
-    undef $me->{sql};
-    undef $me->{build_data}{show};
-    undef @{$me->{build_data}{Showing}};
-    for my $fld (@_) {
-        if (blessed $fld and $fld->isa('DBIx::DBO::Table')) {
-            ouch 'Invalid table field' unless defined $me->_table_idx($fld);
-            push @{$me->{build_data}{Showing}}, $fld;
-            next;
-        }
-        # If the $fld is just a scalar use it as a column name not a value
-        push @{$me->{build_data}{Showing}}, [ $me->_parse_col_val($fld) ];
-    }
-}
-
 =head2 join_on
 
   $query->join_on($table_object, $expression1, $operator, $expression2);
@@ -258,7 +237,7 @@ sub where {
     # If the $fld is just a scalar use it as a column name not a value
     my ($fld, $fld_func, $fld_opt) = $me->_parse_col_val(shift);
     my $op = shift;
-    my ($val, $val_func, $val_opt) = $me->_parse_val(shift, 'Auto');
+    my ($val, $val_func, $val_opt) = $me->_parse_val(shift, Check => 'Auto');
 
     # Validate the fields
     for my $f (@$fld, @$val) {
@@ -387,11 +366,9 @@ sub _add_where {
 sub _parse_col_val {
     my $me = shift;
     my $col = shift;
-    return $me->_parse_val($col, 'Column') if ref $col;
-    for my $tbl ($me->tables) {
-        return [ $tbl->column($col) ] if exists $tbl->{Column_Idx}{$col};
-    }
-    ouch 'No such column: '.$col;
+    my %c = (Check => 'Column', @_);
+    return $me->_parse_val($col, %c) if ref $col;
+    return [ $me->_parse_col($col, $c{Aliases}) ];
 }
 
 =head2 group_by
@@ -411,7 +388,7 @@ sub group_by {
     undef $me->{build_data}{group};
     undef @{$me->{build_data}{GroupBy}};
     for my $col (@_) {
-        my @group = $me->_parse_col_val($col);
+        my @group = $me->_parse_col_val($col, Aliases => 1);
         push @{$me->{build_data}{GroupBy}}, \@group;
     }
 }
@@ -433,7 +410,7 @@ sub order_by {
     undef $me->{build_data}{order};
     undef @{$me->{build_data}{OrderBy}};
     for my $col (@_) {
-        my @order = $me->_parse_col_val($col);
+        my @order = $me->_parse_col_val($col, Aliases => 1);
         push @{$me->{build_data}{OrderBy}}, \@order;
     }
 }
@@ -586,7 +563,8 @@ sub run {
 sub _execute {
     my $me = shift;
     $me->_sql($me->sql, $me->_bind_params_select($me->{build_data}));
-    $me->sth->execute($me->_bind_params_select($me->{build_data}));
+    $me->sth or return;
+    $me->{sth}->execute($me->_bind_params_select($me->{build_data}));
 }
 
 sub _bind_cols_to_hash {
@@ -670,35 +648,6 @@ sub found_rows {
     $me->{Found_Rows};
 }
 
-=head2 sth
-
-  my $sth = $query->sth;
-
-Reutrns the C<DBI> statement handle from the query.
-This will run/rerun the query if needed.
-
-=cut
-
-sub sth {
-    my $me = shift;
-    # Ensure the sql is rebuilt if needed
-    my $sql = $me->sql;
-    $me->{sth} ||= $me->rdbh->prepare($sql);
-}
-
-=head2 finish
-
-  $query->finish;
-
-Calls L<DBI-E<gt>finish|DBI/"finish"> on the statement handle, if it's active.
-
-=cut
-
-sub finish {
-    my $me = shift;
-    $me->{sth}->finish if $me->{sth} and $me->{sth}{Active};
-}
-
 =head2 sql
 
   my $sql = $query->sql;
@@ -734,10 +683,59 @@ sub _build_sql {
     $me->{sql} = $me->_build_sql_select($me->{build_data});
 }
 
+=head2 sth
+
+  my $sth = $query->sth;
+
+Reutrns the C<DBI> statement handle from the query.
+This will run/rerun the query if needed.
+
+=cut
+
+sub sth {
+    my $me = shift;
+    # Ensure the sql is rebuilt if needed
+    my $sql = $me->sql;
+    $me->{sth} ||= $me->rdbh->prepare($sql);
+}
+
+=head2 finish
+
+  $query->finish;
+
+Calls L<DBI-E<gt>finish|DBI/"finish"> on the statement handle, if it's active.
+
+=cut
+
+sub finish {
+    my $me = shift;
+    $me->{sth}->finish if $me->{sth} and $me->{sth}{Active};
+}
+
+=head1 COMMON METHODS
+
+These methods are accessible from all DBIx::DBO* objects.
+
+=head2 dbh
+
+The read-write C<DBI> handle.
+
+=head2 rdbh
+
+The read-only C<DBI> handle, or if there is no read-only connection, the read-write C<DBI> handle.
+
+=head2 do
+
+  $dbo->do($statement)         or die $dbo->dbh->errstr;
+  $dbo->do($statement, \%attr) or die $dbo->dbh->errstr;
+  $dbo->do($statement, \%attr, @bind_values) or die ...
+
+This provides access to L<DBI-E<gt>do|DBI/"do"> method. It defaults to using the read-write C<DBI> handle.
+
 =head2 config
 
-  $query_setting = $dbo->config($option)
-  $dbo->config($option => $query_setting)
+  $query_setting = $dbo->config($option);
+  $dbo->config($option => $query_setting);
 
 Get or set this C<DBIx::DBO::Query> config settings.
 When setting an option, the previous value is returned.
